'''OpenGL extension EXT.render_snorm

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.render_snorm to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL ES 3.0 supports a variety of signed normalized texture and
	renderbuffer formats which are not color-renderable.
	
	This extension enables signed normalized texture and renderbuffer
	formats to be color-renderable.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/render_snorm.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.render_snorm import *
from OpenGL.raw.GLES2.EXT.render_snorm import _EXTENSION_NAME

def glInitRenderSnormEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION