'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_fragment_coverage_to_color'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_fragment_coverage_to_color',error_checker=_errors._error_checker)
GL_FRAGMENT_COVERAGE_COLOR_NV=_C('GL_FRAGMENT_COVERAGE_COLOR_NV',0x92DE)
GL_FRAGMENT_COVERAGE_TO_COLOR_NV=_C('GL_FRAGMENT_COVERAGE_TO_COLOR_NV',0x92DD)
@_f
@_p.types(None,_cs.GLuint)
def glFragmentCoverageColorNV(color):pass
